@@ -6,21 +6,40 @@ describe CssController, type: :controller do
     cache.rmtree if cache.exist?
   end
 
+  def test_file(file)
+    if Rails.version.split('.').first.to_i >= 5
+      get :test, params: { file: 'sass' }
+    else
+      get :test, file: 'sass'
+    end
+  end
+
   it "integrates with Rails and Sass" do
-    get :test, file: 'sass'
+    test_file 'sass'
     expect(response).to be_success
     clear_css = response.body.gsub("\n", " ").squeeze(" ").strip
-    expect(clear_css).to eq "a { -webkit-mask: none; mask: none; }"
+    expect(clear_css).to eq "a { -webkit-mask: none; mask: none }"
   end
 
   if Sprockets::Context.instance_methods.include?(:evaluate)
     it 'supports evaluate' do
-      get :test, file: 'evaluate'
+      test_file 'evaluate'
       expect(response).to be_success
       clear_css = response.body.gsub("\n", ' ').squeeze(' ').strip
       expect(clear_css).to eq 'a { -webkit-mask: none; mask: none }'
     end
   end
+
+  if sprockets_4?
+    it "works with sprockets 4 source maps" do
+      get :test, params: { exact_file: 'sass.css.map' }
+      expect(response).to be_success
+
+      source_map = JSON.parse(response.body)
+      expect(source_map["sources"].first).to(
+        include('spec/app/app/assets/stylesheets/loaded.sass'))
+    end
+  end
 end
 
 describe 'Rake task' do
